import os
class Calc:
    def __init__(self):
        pass
    def sum(self,a,b):
        return a+b
    def subtract(self,a,b):
        return a-b 
    def multiply(self,a,b):
        return a*b
    def divide(self,a,b):
        return a/b

calculator = Calc()


from setuptools import setup

setup(
    name='useless_calc',
    url='https://github.com/jagadeesh-r1/calculate_silly',
    author='Jagadeesh Reddy',
    author_email='mail4jagadeeshreddy@gmail.com',
    packages=['Calculate'],
    version='0.0.1',
    license='GNU General Public License v3.0',
    description='dont use this.',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown'
)